Index: runtime/bin/platform.h |
diff --git a/runtime/bin/platform.h b/runtime/bin/platform.h |
index 233740ecb3b3a0bb8a65924a1a7083f0986a3ed3..38cafbe2ad84b3953e005bb8ae25320a5feb3f8a 100644 |
--- a/runtime/bin/platform.h |
+++ b/runtime/bin/platform.h |
@@ -27,11 +27,12 @@ class Platform { |
// Extracts the local hostname. |
static bool LocalHostname(char* buffer, intptr_t buffer_length); |
// Extracts the environment variables for the current process. |
// The array of strings returned must be deallocated using |
// delete[]. The number of elements in the array is returned |
// in the count argument. |
static char** Environment(intptr_t* count); |
+ static void FreeEnvironment(char** env, intptr_t count); |
private: |
DISALLOW_ALLOCATION(); |
@@ -27,11 +27,12 @@ class Platform { |
// Extracts the local hostname. |
static bool LocalHostname(char* buffer, intptr_t buffer_length); |
- // Extracts the environment variables for the current process. |
- // The array of strings returned must be deallocated using |
- // delete[]. The number of elements in the array is returned |
+ // Extracts the environment variables for the current process. The |
+ // array of strings returned must be deallocated using |
+ // FreeEnvironment. The number of elements in the array is returned |
// in the count argument. |
static char** Environment(intptr_t* count); |